@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2003-2004 Jacek Konieczny <jajcus@jajcus.net>
+# (C) Copyright 2003-2010 Jacek Konieczny <jajcus@jajcus.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License Version
@@ -20,7 +20,7 @@ Normative reference:
   - `JEP 45 <http://www.jabber.org/jeps/jep-0045.html>`__
 """
 
-__revision__="$Id: muccore.py 616 2005-12-26 15:28:56Z jajcus $"
+__revision__="$Id: muccore.py 714 2010-04-05 10:20:10Z jajcus $"
 __docformat__="restructuredtext en"
 
 import libxml2
@@ -28,7 +28,6 @@ import libxml2
 from pyxmpp.utils import to_utf8,from_utf8
 from pyxmpp.xmlextra import common_doc, common_root, common_ns, get_node_ns_uri
 from pyxmpp.presence import Presence
-from pyxmpp.error import ErrorNodeError
 from pyxmpp.iq import Iq
 from pyxmpp.jid import JID
 from pyxmpp import xmlextra
@@ -84,11 +83,11 @@ class MucXBase(StanzaPayloadWrapperObject):
                 xmlextra.replace_ns(self.xmlnode, ns, common_ns)
         elif isinstance(xmlnode,MucXBase):
             if not copy:
-                raise ErrorNodeError,"MucXBase may only be copied"
+                raise TypeError, "MucXBase may only be copied"
             self.xmlnode=xmlnode.xmlnode.docCopyNode(common_doc,1)
             common_root.addChild(self.xmlnode)
         elif xmlnode is not None:
-            raise ErrorNodeError,"Bad MucX constructor argument"
+            raise TypeError, "Bad MucX constructor argument"
         else:
             if parent:
                 self.xmlnode=parent.newChild(None,self.element,None)
@@ -405,7 +404,8 @@ class MucItem(MucItemBase):
         if self.reason:
             n.newTextChild(None,"reason",to_utf8(self.reason))
         n.setProp("affiliation",to_utf8(self.affiliation))
-        n.setProp("role",to_utf8(self.role))
+        if self.role:
+            n.setProp("role",to_utf8(self.role))
         if self.jid:
             n.setProp("jid",to_utf8(self.jid.as_unicode()))
         if self.nick:
