@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2003-2005 Jacek Konieczny <jajcus@jajcus.net>
+# (C) Copyright 2003-2010 Jacek Konieczny <jajcus@jajcus.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License Version
@@ -20,14 +20,15 @@ Normative reference:
   - `RFC 2831 <http://www.ietf.org/rfc/rfc2831.txt>`__
 """
 
-__revision__="$Id: digest_md5.py 559 2005-03-20 18:01:06Z jajcus $"
+__revision__="$Id: digest_md5.py 703 2010-04-03 17:45:43Z jajcus $"
 __docformat__="restructuredtext en"
 
 from binascii import b2a_hex
 import re
-import md5
 import logging
 
+import hashlib
+
 from pyxmpp.sasl.core import ClientAuthenticator,ServerAuthenticator
 from pyxmpp.sasl.core import Failure,Response,Challenge,Success,Failure
 
@@ -78,7 +79,7 @@ def _h_value(s):
 
     :return: MD5 sum of the string.
     :returntype: `str`"""
-    return md5.new(s).digest()
+    return hashlib.md5(s).digest()
 
 def _kd_value(k,s):
     """KD function of the DIGEST-MD5 algorithm.
@@ -171,7 +172,7 @@ def _compute_response_auth(urp_hash,nonce,cnonce,nonce_count,authzid,digest_uri)
             cnonce,"auth",b2a_hex(_h_value(a2)) ) ))
 
 _param_re=re.compile(r'^(?P<var>[^=]+)\=(?P<val>(\"(([^"\\]+)|(\\\")'
-        r'|(\\\\))+\")|([^",]+))(\,(?P<rest>.*))?$')
+        r'|(\\\\))+\")|([^",]+))(\s*\,\s*(?P<rest>.*))?$')
 
 class DigestMD5ClientAuthenticator(ClientAuthenticator):
     """Provides PLAIN SASL authentication for a client.
@@ -341,7 +342,7 @@ class DigestMD5ClientAuthenticator(ClientAuthenticator):
         host=self.password_manager.get_serv_host().encode("us-ascii")
         serv_name=self.password_manager.get_serv_name().encode("us-ascii")
 
-        if serv_name:
+        if serv_name and serv_name != host:
             digest_uri="%s/%s/%s" % (serv_type,host,serv_name)
         else:
             digest_uri="%s/%s" % (serv_type,host)
@@ -446,7 +447,7 @@ class DigestMD5ClientAuthenticator(ClientAuthenticator):
     def finish(self,data):
         """Process success indicator from the server.
 
-        Process any addicional data passed with the success.
+        Process any addiitional data passed with the success.
         Fail if the server was not authenticated.
 
         :Parameters:
@@ -456,13 +457,20 @@ class DigestMD5ClientAuthenticator(ClientAuthenticator):
 
         :return: success or failure indicator.
         :returntype: `sasl.Success` or `sasl.Failure`"""
-        if self.rspauth_checked:
-            return Success(self.username,self.realm,self.authzid)
-        else:
-            self._final_challenge(data)
         if not self.response_auth:
             self.__logger.debug("Got success too early")
             return Failure("bad-success")
+        if self.rspauth_checked:
+            return Success(self.username,self.realm,self.authzid)
+        else:
+            r = self._final_challenge(data)
+            if isinstance(r, Failure):
+                return r
+            if self.rspauth_checked:
+                return Success(self.username,self.realm,self.authzid)
+            else:
+                self.__logger.debug("Something went wrong when processing additional data with success?")
+                return Failure("bad-success")
 
 class DigestMD5ServerAuthenticator(ServerAuthenticator):
     """Provides DIGEST-MD5 SASL authentication for a server."""
