@@ -1,5 +1,5 @@
 #
-# (C) Copyright 2003-2004 Jacek Konieczny <jajcus@jajcus.net>
+# (C) Copyright 2003-2010 Jacek Konieczny <jajcus@jajcus.net>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License Version
@@ -21,7 +21,7 @@ Normative reference:
   - `RFC 3920 <http://www.ietf.org/rfc/rfc3920.txt>`__
 """
 
-__revision__="$Id: stanzaprocessor.py 668 2007-01-05 16:24:08Z jajcus $"
+__revision__="$Id: stanzaprocessor.py 714 2010-04-05 10:20:10Z jajcus $"
 __docformat__="restructuredtext en"
 
 import libxml2
@@ -107,19 +107,21 @@ class StanzaProcessor:
                 ufr=fr.as_unicode()
             else:
                 ufr=None
-            if self._iq_response_handlers.has_key((sid,ufr)):
-                key=(sid,ufr)
-            elif ( (fr==self.peer or fr==self.me)
-                    and self._iq_response_handlers.has_key((sid,None))):
-                key=(sid,None)
-            else:
-                return False
-            res_handler, err_handler = self._iq_response_handlers[key]
-            if stanza.get_type()=="result":
+            res_handler = err_handler = None
+            try:
+                res_handler, err_handler = self._iq_response_handlers.pop((sid,ufr))
+            except KeyError:
+                if ( (fr==self.peer or fr==self.me or fr==self.me.bare()) ):
+                    try:
+                        res_handler, err_handler = self._iq_response_handlers.pop((sid,None))
+                    except KeyError:
+                        pass
+                if None is res_handler is err_handler:
+                    return False
+            if typ=="result":
                 response = res_handler(stanza)
             else:
                 response = err_handler(stanza)
-            del self._iq_response_handlers[key]
             self.process_response(response)
             return True
 
